@@ -40,9 +40,6 @@ class Q_DECL_HIDDEN LdapClient::Private
 public:
     Private(LdapClient *qq)
         : q(qq)
-        , mJob(nullptr)
-        , mActive(false)
-        , mClientNumber(0)
     {
     }
 
@@ -57,23 +54,22 @@ public:
     void finishCurrentObject();
 
     void slotData(KIO::Job *, const QByteArray &data);
-    void slotData(const QByteArray &data);
     void slotInfoMessage(KJob *, const QString &info, const QString &);
     void slotDone();
 
-    LdapClient *q;
+    LdapClient *q = nullptr;
 
     KLDAP::LdapServer mServer;
     QString mScope;
     QStringList mAttrs;
 
-    QPointer<KJob> mJob;
-    bool mActive;
+    QPointer<KJob> mJob = nullptr;
+    bool mActive = false;
 
     KLDAP::LdapObject mCurrentObject;
     KLDAP::Ldif mLdif;
-    int mClientNumber;
-    int mCompletionWeight;
+    int mClientNumber = 0;
+    int mCompletionWeight = 0;
 };
 
 LdapClient::LdapClient(int clientNumber, QObject *parent)
@@ -141,13 +137,19 @@ void LdapClient::startQuery(const QString &filter)
 
     d->startParseLDIF();
     d->mActive = true;
-    d->mJob = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
-    connect(d->mJob, SIGNAL(data(KIO::Job *,QByteArray)),
-            this, SLOT(slotData(KIO::Job *,QByteArray)));
-    connect(d->mJob, SIGNAL(infoMessage(KJob *,QString,QString)),
-            this, SLOT(slotInfoMessage(KJob *,QString,QString)));
-    connect(d->mJob, SIGNAL(result(KJob *)),
-            this, SLOT(slotDone()));
+    KIO::TransferJob *transfertJob = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
+    d->mJob = transfertJob;
+    connect(transfertJob, &KIO::TransferJob::data, this, [this](KIO::Job *job, const QByteArray &data) {
+        d->slotData(job, data);
+    });
+    connect(d->mJob.data(), &KIO::TransferJob::infoMessage, this,
+            [this](KJob *job, const QString &str, const QString &val) {
+        d->slotInfoMessage(job, str, val);
+    });
+    connect(d->mJob.data(), &KIO::TransferJob::result,
+            this, [this]() {
+        d->slotDone();
+    });
 }
 
 void LdapClient::cancelQuery()
@@ -165,11 +167,6 @@ void LdapClient::Private::slotData(KIO::Job *, const QByteArray &data)
     parseLDIF(data);
 }
 
-void LdapClient::Private::slotData(const QByteArray &data)
-{
-    parseLDIF(data);
-}
-
 void LdapClient::Private::slotInfoMessage(KJob *, const QString &info, const QString &)
 {
     qCDebug(LDAPCLIENT_LOG) << "Job said :" << info;
@@ -228,10 +225,14 @@ void LdapClient::Private::finishCurrentObject()
             // No explicit mail address found so far?
             // Fine, then we use the address stored in the DN.
             QString sMail;
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             const QStringList lMail = mCurrentObject.dn().toString().split(QStringLiteral(",dc="), QString::SkipEmptyParts);
+#else
+            const QStringList lMail = mCurrentObject.dn().toString().split(QStringLiteral(",dc="), Qt::SkipEmptyParts);
+#endif
             const int n = lMail.count();
             if (n) {
-                if (lMail.first().toLower().startsWith(QStringLiteral("cn="))) {
+                if (lMail.first().startsWith(QLatin1String("cn="), Qt::CaseInsensitive)) {
                     sMail = lMail.first().simplified().mid(3);
                     if (1 < n) {
                         sMail.append(QLatin1Char('@'));
