@@ -5,7 +5,7 @@
  *
  *      Ported to KABC by Daniel Molkentin <molkentin@kde.org>
  *
- * Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -190,12 +190,14 @@ void LdapClientSearch::Private::readConfig()
             ldapClient->setAttributes(mAttributes);
 
             q->connect(ldapClient, &LdapClient::result,
-                       q, [this](const LdapClient &client, const KLDAP::LdapObject &obj) { slotLDAPResult(client, obj); });
+                       q, [this](const LdapClient &client, const KLDAP::LdapObject &obj) {
+                slotLDAPResult(client, obj);
+            });
             q->connect(ldapClient, &LdapClient::done,
                        q, [this]() {
                 slotLDAPDone();
             });
-            q->connect(ldapClient, QOverload<const QString &>::of(&LdapClient::error),
+            q->connect(ldapClient, qOverload<const QString &>(&LdapClient::error),
                        q, [this](const QString &str) {
                 slotLDAPError(str);
             });
