@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -39,9 +39,9 @@ AddresseeLineEditManager::AddresseeLineEditManager()
     : mShowOU(false)
     , mAutoGroupExpand(false)
     , mCompletion(new KMailCompletion)
-    , mAddresseeLineEditAkonadi(new AddresseeLineEditAkonadi(this))
+    , mAddresseeLineEditAkonadi(new AddresseeLineEditAkonadi)
     , mAddressessLineEditLdap(new AddresseeLineEditLdap(this))
-    , mAddressessLineEditBaloo(new AddresseeLineEditBaloo(this))
+    , mAddressessLineEditBaloo(new AddresseeLineEditBaloo)
     , mNetworkConfigMgr(new QNetworkConfigurationManager(QCoreApplication::instance()))
 {
     KConfigGroup group(KSharedConfig::openConfig(), "AddressLineEdit");
